function varargout=configure(varargin)
% FUNCTION fc_oogmsh.configure()
%   Configures the toolbox/package by setting gmsh path, meshes default 
%   directory and .geo files default directory.
%   Theses informations will be stored in ... file.
%
% <COPYRIGHT>
  [conffile,isFileExists]=fc_oogmsh.getLocalConfFile();
  if isFileExists
    run(conffile);
  else
    fullname=mfilename('fullpath');
    I=strfind(fullname,filesep);
    Path=fullname(1:(I(end-1)-1));
    gmsh_bin='/usr/bin/gmsh';
    mesh_dir=[Path,filesep,'meshes'];
    geo_dir=[Path,filesep,'geodir'];
    fc_tools_dir=''; % empty if pkg or toolbox in path
  end
  p = inputParser;
  p.addParamValue('gmsh_bin',gmsh_bin,@ischar);
  p.addParamValue('mesh_dir',mesh_dir,@ischar);
  p.addParamValue('geo_dir',geo_dir,@ischar);
  p.addParamValue('fc_tools_dir',fc_tools_dir,@ischar);
  %p.addParamValue('force',false,@islogical); 
  p.parse(varargin{:});
  R=p.Results;
  
  if ~isdir(R.mesh_dir), error('Not a directory :\n''mesh_dir''=%s\n', R.mesh_dir); end
  if ~isdir(R.geo_dir), error('Not a directory :\n''geo_dir''=%s\n', R.geo_dir); end
  if exist(R.gmsh_bin)~=2, error('Not a file :\n''gmsh_bin''=%s\n', R.gmsh_bin); end
  
  fprintf('Write in %s ...\n',conffile);
  fid=fopen(conffile,'w');
  if (fid==0), error('Unable to open file :\n %s\n',conffile);end
  fprintf(fid,'%% Automaticaly generated with fc_oogmsh.configure()\n');
  fprintf(fid,'gmsh_bin=''%s'';\n',R.gmsh_bin);
  fprintf(fid,'mesh_dir=''%s'';\n',R.mesh_dir);
  fprintf(fid,'geo_dir=''%s'';\n',R.geo_dir);
  fprintf(fid,'fc_tools_dir=''%s'';\n',R.fc_tools_dir);
  fclose(fid);
  fprintf('  -> done\n');
  if nargout==1,varargout{1}=conffile;end
end

